<?php
/** add single metaboxes */
if ( function_exists( 'rb_register_meta_boxes' ) ) {
	add_filter( 'rb_meta_boxes', 'pixwell_register_metaboxes' );
}

/** metaboxes configs */
function pixwell_register_metaboxes( $pixwell_meta = array() ) {

	$pixwell_meta[] = array(
		'id'         => 'pixwell_post_options',
		'title'      => esc_html__( 'Pixwell Post Options', 'pixwell' ),
		'context'    => 'normal',
		'post_types' => array( 'post' ),
		'tabs'       => array(
			array(
				'id'     => 'pixwell-general',
				'title'  => esc_html__( 'General', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'title_tagline',
						'name'    => esc_html__( 'Title Tagline', 'pixwell' ),
						'desc'    => esc_html__( 'Input a post tagline.', 'pixwell' ),
						'info'    => esc_html__( 'The tagline will display under the single post title.', 'pixwell' ),
						'type'    => 'textarea',
						'default' => ''
					),
					array(
						'name'        => esc_html__( 'Primary Category', 'pixwell' ),
						'id'          => 'primary_cat',
						'type'        => 'category_select',
						'taxonomy'    => 'category',
						'placeholder' => esc_html__( 'Select a Primary Category', 'pixwell' ),
						'desc'        => esc_html__( 'Set a primary category for this post.', 'pixwell' ),
						'info'        => esc_html__( 'This setting is helpful if this post has many categories.', 'pixwell' ),
						'default'     => ''
					),
					array(
						'id'      => 'meta_custom',
						'name'    => esc_html__( 'Custom Meta - Value', 'pixwell' ),
						'desc'    => esc_html__( 'Input a custom meta for this post.', 'pixwell' ),
						'info'    => esc_html__( 'Navigate to "Theme Options > Styles & Design > Custom Meta" for more settings.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'single_top',
						'name'    => esc_html__( 'Top Content Ad', 'pixwell' ),
						'desc'    => esc_html__( 'Show a widgets section at the top of the post content.', 'pixwell' ),
						'info'    => esc_html__( 'Navigate to "Appearance > Widgets > Single Content - Top Advert Section" to add widgets.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'1'  => esc_html__( 'Enable', 'pixwell' ),
							'-1' => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => '1'
					),
					array(
						'id'      => 'single_bottom',
						'name'    => esc_html__( 'Bottom Content Ad', 'pixwell' ),
						'desc'    => esc_html__( 'Show a widgets section at the bottom of the post content.', 'pixwell' ),
						'info'    => esc_html__( 'Navigate to "Appearance > Widgets > Single Content - Bottom Advert Section" to add widgets.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'1'  => esc_html__( 'Enable', 'pixwell' ),
							'-1' => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => '1'
					),
					array(
						'id'      => 'single_schema',
						'name'    => esc_html__( 'Article Markup for SEO', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or the article markup for this post.', 'pixwell' ),
						'info'    => esc_html__( 'Select "disable" if you use a 3rd plugin to create SEO tags.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Options', 'pixwell' ),
							'-1'      => esc_html__( 'Enable', 'pixwell' ),
							'1'       => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => 'default'
					)
				)
			),
			array(
				'id'     => 'pixwell-layout',
				'title'  => esc_html__( 'Layout', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'post_layout',
						'name'    => esc_html__( 'Single Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for this post.', 'pixwell' ),
						'type'    => 'image_select',
						'class'   => 'big',
						'options' => pixwell_add_settings_meta_single_layout(),
						'default' => 'default'
					),
					array(
						'id'      => 'sidebar_name',
						'name'    => esc_html__( 'Sidebar Name', 'pixwell' ),
						'desc'    => esc_html__( 'Assign a sidebar for this post.', 'pixwell' ),
						'info'    => esc_html__( 'The sidebar will not appear on the layout without sidebar position.', 'pixwell' ),
						'type'    => 'select',
						'options' => pixwell_add_settings_sidebar_name( true ),
						'default' => 'default'
					),
					array(
						'id'      => 'sidebar_pos',
						'name'    => esc_html__( 'Sidebar Position', 'pixwell' ),
						'desc'    => esc_html__( 'Select a position for the post sidebar.', 'pixwell' ),
						'class'   => 'sidebar-select',
						'type'    => 'image_select',
						'options' => pixwell_add_settings_meta_sidebar_pos(),
						'default' => 'default'
					),
					array(
						'id'      => 'feat_size',
						'name'    => esc_html__( 'Featured Image Size', 'pixwell' ),
						'desc'    => esc_html__( 'Select a quality for the post feautred image.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default From Theme Options', 'pixwell' ),
							'full'    => esc_html__( 'Full Size', 'pixwell' ),
							'crop'    => esc_html__( 'Crop Size', 'pixwell' )
						),
						'default' => 'default'
					),
					array(
						'id'      => 'feat_credit',
						'name'    => esc_html__( 'Featured Credit Text', 'pixwell' ),
						'desc'    => esc_html__( 'Input a credit text for the featured image.', 'pixwell' ),
						'info'    => esc_html__( 'the image title will be shown if this setting is empty.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					)
				)
			),
			/** post review */
			array(
				'id'     => 'pixwell-review',
				'title'  => esc_html__( 'Post Review', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'post_review',
						'name'    => esc_html__( 'Post Review', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable product review feature for this post.', 'pixwell' ),
						'type'    => 'select',
						'class'   => 'ruby-review-checkbox',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' )
						),
						'default' => '-1'
					),
					array(
						'id'      => 'review_users',
						'name'    => esc_html__( 'Users Review', 'pixwell' ),
						'desc'    => esc_html__( 'Replace the comment box with a review box for this post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( '- Default form Theme Options -', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'review_style',
						'name'    => esc_html__( 'Review Box Style', 'pixwell' ),
						'desc'    => esc_html__( 'Select box review style.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Dark --', 'pixwell' ),
							'1'  => esc_html__( 'Light', 'pixwell' )
						),
						'default' => '-1'
					),
					array(
						'id'   => 'review_feat',
						'name' => esc_html__( 'Review Featured Image', 'pixwell' ),
						'desc' => esc_html__( 'Upload featured header image for your review box.', 'pixwell' ),
						'type' => 'file'
					),
					array(
						'id'   => 'review_label_1',
						'name' => esc_html__( 'Criteria 1 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 1.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'name'  => esc_html__( 'Criteria 1 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 1. The input should is a number between 1 and 5.', 'pixwell' ),
						'id'    => 'review_star_1',
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_2',
						'name' => esc_html__( 'Criteria 2 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 2.', 'pixwell' ),
						'type' => 'text',
					),
					array(
						'id'    => 'review_star_2',
						'name'  => esc_html__( 'Criteria 2 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 2. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_3',
						'name' => esc_html__( 'Criteria 3 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 3.', 'pixwell' ),
						'type' => 'text',
					),
					array(
						'id'    => 'review_star_3',
						'name'  => esc_html__( 'Criteria 3 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 3. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_4',
						'name' => esc_html__( 'Criteria 4 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 4.', 'pixwell' ),
						'type' => 'text',
					),
					array(
						'id'    => 'review_star_4',
						'name'  => esc_html__( 'Criteria 4 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 4. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_5',
						'name' => esc_html__( 'Criteria 5 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 5.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'    => 'review_star_5',
						'name'  => esc_html__( 'Criteria 5 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 1. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_6',
						'name' => esc_html__( 'Criteria 6 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 6.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'    => 'review_star_6',
						'name'  => esc_html__( 'Criteria 6 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 6. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_label_7',
						'name' => esc_html__( 'Criteria 7 - Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a label for criteria 6.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'    => 'review_star_7',
						'name'  => esc_html__( 'Criteria 7 - Stars', 'pixwell' ),
						'desc'  => esc_html__( 'Input number of stars for criteria 7. The input should is a number between 1 and 5.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'   => 'review_meta',
						'name' => esc_html__( 'Short Meta Info', 'pixwell' ),
						'desc' => esc_html__( 'Input short meta info to display before the review score, For example: Good, Bad...', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'   => 'review_pros',
						'name' => esc_html__( 'Pros Summary Section', 'pixwell' ),
						'desc' => esc_html__( 'Input pros summary for this review, separated by "/" example: positive 1/positive 2/positive 3', 'pixwell' ),
						'type' => 'textarea'
					),
					array(
						'id'   => 'review_cons',
						'name' => esc_html__( 'Cons Summary Section', 'pixwell' ),
						'desc' => esc_html__( 'Input cons summary for this review, separated by "/" example: negative 1/negative 2/negative 3', 'pixwell' ),
						'type' => 'textarea'
					),
					array(
						'id'   => 'review_summary',
						'name' => esc_html__( 'Final Summary Section', 'pixwell' ),
						'desc' => esc_html__( 'Input final summary for this review.', 'pixwell' ),
						'type' => 'textarea'
					),
					array(
						'id'   => 'review_button',
						'name' => esc_html__( 'Offer Label', 'pixwell' ),
						'desc' => esc_html__( 'Input a offer label (Call to action) for this product review.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'   => 'review_destination',
						'name' => esc_html__( 'Offer Destination URL', 'pixwell' ),
						'desc' => esc_html__( 'Input the destination URL of the offer.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'   => 'preview_price',
						'name' => esc_html__( 'Offer Price', 'pixwell' ),
						'desc' => esc_html__( 'Input the price of the offer.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'          => 'review_currency',
						'name'        => esc_html__( 'Offer Currency', 'pixwell' ),
						'placeholder' => 'USD',
						'desc'        => esc_html__( 'Input a currency of the offer.', 'pixwell' ),
						'type'        => 'text'
					),
					array(
						'id'          => 'review_price_valid',
						'name'        => esc_html__( 'Offer Price Valid Until', 'pixwell' ),
						'placeholder' => ( 'yyyy-mm-dd' ),
						'desc'        => esc_html__( 'Input the valid until date for this offer, Ensure you input right format: yyyy-mm-dd.', 'pixwell' ),
						'type'        => 'text'
					)
				)
			),
			/** post video */
			array(
				'id'     => 'pixwell-video',
				'title'  => esc_html__( 'Video Format', 'pixwell' ),
				'info'   => esc_html__( 'Select "Video" in the Post Format setting in the right pane to work.', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'video_url',
						'name'    => esc_html__( 'Video URL', 'pixwell' ),
						'desc'    => esc_html__( 'Input your video link, support: Youtube, Vimeo, DailyMotion.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'   => 'video_embed',
						'name' => esc_html__( 'Iframe Embed Code', 'pixwell' ),
						'desc' => esc_html__( 'Input an iframe embed code.', 'pixwell' ),
						'type' => 'textarea'
					),
					array(
						'id'   => 'video_hosted',
						'name' => esc_html__( 'Self-Hosted Video', 'pixwell' ),
						'desc' => esc_html__( 'Upload your video file, support: mp4, m4v, webm, ogv, wmv, flv files.', 'pixwell' ),
						'type' => 'file'
					),
					array(
						'id'      => 'video_autoplay',
						'name'    => esc_html__( 'Autoplay Video', 'pixwell' ),
						'desc'    => esc_html__( 'enable or disable autoplay video for this post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Options', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => 'default'
					),
				)
			),
			/** post audio */
			array(
				'id'     => 'pixwell-audio',
				'title'  => esc_html__( 'Audio Format', 'pixwell' ),
				'info'   => esc_html__( 'Select "Audio" option in "Post Format" settings on the right pane to work.', 'pixwell' ),
				'fields' => array(
					array(
						'id'   => 'audio_url',
						'name' => esc_html__( 'Audio URL', 'pixwell' ),
						'desc' => esc_html__( 'Input your audio URL, support: SoundCloud, MixCloud.', 'pixwell' ),
						'type' => 'text'
					),
					array(
						'id'   => 'audio_embed',
						'name' => esc_html__( 'Iframe Embed Code', 'pixwell' ),
						'desc' => esc_html__( 'Input an iframe embed code.', 'pixwell' ),
						'type' => 'textarea'
					),
					array(
						'id'   => 'audio_hosted',
						'name' => esc_html__( 'Self-Hosted Audio', 'pixwell' ),
						'desc' => esc_html__( 'Upload your audio file, support: mp3, ogg, wma, m4a, wav files.', 'pixwell' ),
						'type' => 'file'
					),
					array(
						'id'      => 'post_podcast',
						'name'    => esc_html__( 'Single Podcast Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Show the podcast layout for this audio post.', 'pixwell' ),
						'class'   => 'big',
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Options', 'pixwell' ),
							'1'       => esc_html__( 'Disable', 'pixwell' ),
							'2'       => esc_html__( 'Enable', 'pixwell' )
						),
						'default' => 'default'
					),
				)
			),
			array(
				'id'     => 'pixwell-gallery',
				'title'  => esc_html__( 'Gallery Format', 'pixwell' ),
				'info'   => esc_html__( 'Select "Gallery" option in "Post Format" settings on the right pane to work.', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'gallery_data',
						'name'    => esc_html__( 'Upload Gallery', 'pixwell' ),
						'desc'    => esc_html__( 'Upload your images for this gallery', 'pixwell' ),
						'info'    => esc_html__( 'The popup will collect the title, caption and description of attachments to show.', 'pixwell' ),
						'type'    => 'images',
						'default' => ''
					),
					array(
						'id'      => 'gallery_layout',
						'name'    => esc_html__( 'Gallery Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for this gallery post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default From Theme Options', 'pixwell' ),
							'slide'   => esc_html__( 'Slider', 'pixwell' ),
							'list'    => esc_html__( 'List', 'pixwell' ),
							'grid'    => esc_html__( 'Small Grid', 'pixwell' )

						),
						'default' => 'default'
					)
				)
			),
			array(
				'id'     => 'pixwell-left-side',
				'title'  => esc_html__( 'Left Content', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'single_left',
						'name'    => esc_html__( 'Left Content Section', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the left side section.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Options', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => 'default'
					),
					array(
						'id'      => 'single_left_article',
						'name'    => esc_html__( 'Recommended Article', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the recommended articles.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Options', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' )
						),
						'default' => 'default'
					),
				)
			),
			/** Source/Via */
			array(
				'id'     => 'pixwell-via',
				'title'  => esc_html__( 'Source/Via', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'source_name',
						'name'    => esc_html__( 'Source Name', 'pixwell' ),
						'desc'    => esc_html__( 'Input a source name for this post.', 'pixwell' ),
						'info'    => esc_html__( 'These elements will appear under the post tags in post content.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'source_url',
						'name'    => esc_html__( 'Source URL', 'pixwell' ),
						'desc'    => esc_html__( 'Input a source URL for this post.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'via_name',
						'name'    => esc_html__( 'Via Name', 'pixwell' ),
						'desc'    => esc_html__( 'Input a via name for this post.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'via_url',
						'name'    => esc_html__( 'via URL', 'pixwell' ),
						'desc'    => esc_html__( 'Input a via URL for this post.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					)
				)
			),
			array(
				'id'     => 'pixwell-shop',
				'title'  => esc_html__( 'Shop The Post', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'shop_post',
						'name'    => esc_html__( 'Shop the Post', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable Shop the Post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' )
						),
						'default' => '-1'
					),
					array(
						'id'      => 'shop_post_position',
						'name'    => esc_html__( 'Position', 'pixwell' ),
						'desc'    => esc_html__( 'Where to display this section.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'top'    => esc_html__( 'Top Content', 'pixwell' ),
							'bottom' => esc_html__( 'Bottom Content', 'pixwell' )
						),
						'default' => 'top'
					),
					array(
						'id'      => 'shop_post_title',
						'name'    => esc_html__( 'Header', 'pixwell' ),
						'desc'    => esc_html__( 'Input a heading for this section.', 'pixwell' ),
						'type'    => 'text',
						'default' => esc_html__( 'Shop This Post', 'pixwell' )
					),
					array(
						'id'      => 'shop_post_embed',
						'name'    => esc_html__( 'Embed Code', 'pixwell' ),
						'desc'    => esc_html__( 'Input your embed product code.', 'pixwell' ),
						'info'    => esc_html__( 'Leave this setting blank to use Woocommerce products.', 'pixwell' ),
						'type'    => 'textarea',
						'default' => ''
					),
					array(
						'id'          => 'shop_post_wc',
						'name'        => esc_html__( 'or Woocommerce Product IDs', 'pixwell' ),
						'placeholder' => '1000,1001,1002',
						'desc'        => esc_html__( 'Input product category IDs.', 'pixwell' ),
						'info'        => esc_html__( 'Separated product tag ids by comma. For example: 1000,1001,1002', 'pixwell' ),
						'type'        => 'text',
						'default'     => ''
					),
				)
			),
			array(
				'id'     => 'pixwell-sponsor',
				'title'  => esc_html__( 'Sponsored Post', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'sponsor_post',
						'name'    => esc_html__( 'Sponsored Post', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the sponsored post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' )
						),
						'default' => '-1'
					),
					array(
						'id'      => 'sponsor_url',
						'name'    => esc_html__( 'Sponsor URL', 'pixwell' ),
						'desc'    => esc_html__( 'Input a sponsor website URL.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'sponsor_name',
						'name'    => esc_html__( 'Sponsor Name', 'pixwell' ),
						'desc'    => esc_html__( 'Input a sponsor brand name.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'   => 'sponsor_logo',
						'name' => esc_html__( 'Sponsor Logo', 'pixwell' ),
						'desc' => esc_html__( 'Upload a sponsor brand logo.', 'pixwell' ),
						'type' => 'file'
					),
					array(
						'id'      => 'sponsor_redirect',
						'name'    => esc_html__( 'Directly Redirect', 'pixwell' ),
						'desc'    => esc_html__( 'Immediately redirect to the sponsor website when clicking on the post title.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' )
						),
					),
				)
			),
			array(
				'id'     => 'pixwell-shares',
				'title'  => 'Fake Shares & Views',
				'fields' => array(
					array(
						'id'      => 'start_share',
						'name'    => esc_html__( 'Fake Shares Value', 'pixwell' ),
						'desc'    => esc_html__( 'Input a fake shares number for this post.', 'pixwell' ),
						'info'    => esc_html__( 'Leave blank if you want to display real data from Facebook and Pinterest', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
					array(
						'id'      => 'start_view',
						'name'    => esc_html__( 'Fake Views Value', 'pixwell' ),
						'desc'    => esc_html__( 'Input a fake view number for this post.', 'pixwell' ),
						'info'    => esc_html__( 'The view meta requests the "Post Views Counter" plugin to run.', 'pixwell' ),
						'type'    => 'text',
						'default' => ''
					),
				)
			),
			array(
				'id'     => 'pixwell-table-contents',
				'title'  => 'Table of Contents',
				'fields' => array(
					array(
						'id'      => 'table_contents_post',
						'name'    => esc_html__( 'Table of Contents', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the table content for this post.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( '-- Default from Theme Options --', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' ),
						),
					),
					array(
						'id'      => 'table_contents_layout',
						'name'    => esc_html__( 'layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for the table of contents.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( '- Default -', 'pixwell' ),
							'1'       => esc_html__( 'Half Width', 'pixwell' ),
							'2'       => esc_html__( 'Full Width (2 Columns)', 'pixwell' ),
							'3'       => esc_html__( 'Full Width (1 Column)', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'table_contents_enable',
						'type'    => 'text',
						'name'    => esc_html__( 'At least H tags', 'pixwell' ),
						'desc'    => esc_html__( 'Input a minimum number of the H tags for starting to show.', 'pixwell' ),
						'default' => ''
					),
					array(
						'id'      => 'table_contents_position',
						'type'    => 'text',
						'name'    => esc_html__( 'Display Position', 'pixwell' ),
						'desc'    => esc_html__( 'Input a position (After x paragraph) to display the table of contents.', 'pixwell' ),
						'default' => ''
					),
				)
			),
		)
	);

	/**
	 * page options
	 */
	$pixwell_meta[] = array(
		'id'         => 'pixwell_page_options',
		'title'      => esc_html__( 'Pixwell Page Options', 'pixwell' ),
		'context'    => 'normal',
		'post_types' => array( 'page' ),
		'tabs'       => array(
			array(
				'id'     => 'pixwell-page-header',
				'title'  => esc_html__( 'Site Header', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'header_float',
						'name'    => esc_html__( 'Transparent Header', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the site header transparent for this page.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' ),
						),
						'default' => '-1'
					),
					array(
						'id'      => 'navbar_border',
						'name'    => esc_html__( 'Border for Header 3', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the bottom border style for the header 3.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' ),
						),
						'default' => '-1'
					),
					array(
						'id'      => 'header_banner_border',
						'name'    => esc_html__( 'Border for Header 7', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the bottom border style for the header 7.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' ),
						),
						'default' => '-1'
					)
				)
			),
			array(
				'id'     => 'pixwell-page-single',
				'title'  => esc_html__( 'for Single Page', 'pixwell' ),
				'info'   => esc_html__( 'These settings below will only apply to the single page that is without builders.', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'page_layout',
						'name'    => esc_html__( 'Content Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable this page sidebar area.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Option', 'pixwell' ),
							'-1'      => esc_html__( 'Full Width', 'pixwell' ),
							'1'       => esc_html__( 'Content with Sidebar', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'page_max_width',
						'name'    => esc_html__( 'Full Width - Content Width', 'pixwell' ),
						'desc'    => esc_html__( 'Input a max-width value (in px) for this page.', 'pixwell' ),
						'info'    => esc_html__( 'This setting only apply to the content layout without the sidebar.', 'pixwell' ),
						'type'    => 'text',
						'class'   => 'input-small',
						'default' => ''
					),
					array(
						'id'      => 'page_title',
						'name'    => esc_html__( 'Page Header', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable this single page header.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Option', 'pixwell' ),
							'-1'      => esc_html__( 'Enable', 'pixwell' ),
							'1'       => esc_html__( 'Disable', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'page_header_layout',
						'name'    => esc_html__( 'Header Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for this single page header.', 'pixwell' ),
						'info'    => esc_html__( 'The "Full Background" option request a featured image to work.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( 'Default from Theme Option', 'pixwell' ),
							'-1'      => esc_html__( 'Classic', 'pixwell' ),
							'1'       => esc_html__( 'Full Background', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'page_sidebar_name',
						'name'    => esc_html__( 'Assign a Sidebar', 'pixwell' ),
						'desc'    => esc_html__( 'Assign a sidebar for this single page.', 'pixwell' ),
						'options' => pixwell_add_settings_sidebar_name( true ),
						'type'    => 'select',
						'default' => 'default'
					),
					array(
						'id'      => 'page_sidebar_pos',
						'name'    => esc_html__( 'Sidebar Position', 'pixwell' ),
						'desc'    => esc_html__( 'Select a sidebar position for this single page.', 'pixwell' ),
						'class'   => 'sidebar-select',
						'type'    => 'image_select',
						'options' => pixwell_add_settings_meta_sidebar_pos(),
						'default' => 'default'
					),
					array(
						'id'      => 'table_contents_page',
						'name'    => esc_html__( 'Table of Contents', 'pixwell' ),
						'desc'    => esc_html__( 'Show table of contents section in the page content.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( '-- Default from Theme Options --', 'pixwell' ),
							'1'       => esc_html__( 'Enable', 'pixwell' ),
							'-1'      => esc_html__( 'Disable', 'pixwell' ),
						),
					),
					array(
						'id'      => 'table_contents_layout',
						'name'    => esc_html__( 'Table of Contents Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for the table of contents.', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'default' => esc_html__( '- Default -', 'pixwell' ),
							'1'       => esc_html__( 'Half Width', 'pixwell' ),
							'2'       => esc_html__( 'Full Width (2 Columns)', 'pixwell' ),
							'3'       => esc_html__( 'Full Width (1 Column)', 'pixwell' ),
						),
						'default' => 'default'
					),
					array(
						'id'      => 'table_contents_enable',
						'type'    => 'text',
						'name'    => esc_html__( 'At least H tags', 'pixwell' ),
						'desc'    => esc_html__( 'Input a minimum number of the H tags for starting to show.', 'pixwell' ),
						'default' => ''
					),
					array(
						'id'      => 'table_contents_position',
						'type'    => 'text',
						'name'    => esc_html__( 'Display Position', 'pixwell' ),
						'desc'    => esc_html__( 'Input a position (After x paragraph) to display the table of contents box.', 'pixwell' ),
						'default' => ''
					),
				)
			),
			array(
				'id'     => 'pixwell-page-composer',
				'title'  => esc_html__( 'for Ruby Composer', 'pixwell' ),
				'info'   => esc_html__( 'These settings bellow will only apply to the "Ruby Composer" page.', 'pixwell' ),
				'fields' => array(
					array(
						'id'      => 'composer_blog',
						'name'    => esc_html__( 'Latest Blog', 'pixwell' ),
						'desc'    => esc_html__( 'Enable or disable the blog.', 'pixwell' ),
						'info'    => esc_html__( 'the latest blog (as the index.php) with a pagination at the bottom page', 'pixwell' ),
						'type'    => 'select',
						'options' => array(
							'-1' => esc_html__( '-- Disable --', 'pixwell' ),
							'1'  => esc_html__( 'Enable', 'pixwell' )
						),
						'default' => '-1'
					),
					array(
						'id'      => 'composer_blog_title',
						'name'    => esc_html__( 'Block Heading', 'pixwell' ),
						'desc'    => esc_html__( 'Input a heading for this section.', 'pixwell' ),
						'type'    => 'text',
						'default' => esc_html__( 'The Latest News', 'pixwell' )
					),
					array(
						'id'      => 'composer_blog_layout',
						'name'    => esc_html__( 'Blog Layout', 'pixwell' ),
						'desc'    => esc_html__( 'Select a layout for the blog.', 'pixwell' ),
						'type'    => 'image_select',
						'class'   => 'big',
						'options' => array(
							'classic'   => get_theme_file_uri( 'assets/images/ct-classic.png' ),
							'ct_list'   => get_theme_file_uri( 'assets/images/ct-list.png' ),
							'ct_grid_1' => get_theme_file_uri( 'assets/images/ct-grid-1.png' ),
							'ct_grid_2' => get_theme_file_uri( 'assets/images/ct-grid-2.png' ),
							'fw_grid_1' => get_theme_file_uri( 'assets/images/fw-grid-1.png' ),
							'fw_grid_2' => get_theme_file_uri( 'assets/images/fw-grid-2.png' ),
							'fw_grid_3' => get_theme_file_uri( 'assets/images/fw-grid-3.png' ),
							'fw_list_1' => get_theme_file_uri( 'assets/images/fw-list-1.png' ),
							'fw_list_2' => get_theme_file_uri( 'assets/images/fw-list-2.png' )
						),
						'default' => 'classic'
					),
					array(
						'id'      => 'composer_blog_posts_per_page',
						'name'    => esc_html__( 'Posts per Page', 'pixwell' ),
						'desc'    => esc_html__( 'Input number of posts per page.', 'pixwell' ),
						'type'    => 'text',
						'class'   => 'input-small',
						'default' => '6'
					),
					array(
						'id'    => 'composer_blog_offset',
						'name'  => esc_html__( 'Post Offset', 'pixwell' ),
						'desc'  => esc_html__( 'Input a offset (number of posts to pass over) for the blog.', 'pixwell' ),
						'type'  => 'text',
						'class' => 'input-small'
					),
					array(
						'id'      => 'composer_blog_pagination',
						'name'    => esc_html__( 'Pagination', 'pixwell' ),
						'desc'    => esc_html__( 'Select pagination type for this section.', 'pixwell' ),
						'type'    => 'select',
						'options' => pixwell_add_settings_blog_pagination( false ),
						'default' => 'number'
					),
					array(
						'id'      => 'composer_blog_sidebar_name',
						'type'    => 'select',
						'name'    => esc_html__( 'Assign a Sidebar', 'pixwell' ),
						'desc'    => esc_html__( 'Assign a sidebar for the category pages.', 'pixwell' ),
						'info'    => esc_html__( 'The sidebar will not appear on the layout without sidebar position.', 'pixwell' ),
						'options' => pixwell_add_settings_sidebar_name( false ),
						'default' => 'pixwell_sidebar_default'
					),
					array(
						'id'      => 'composer_blog_sidebar_pos',
						'name'    => esc_html__( 'Sidebar Position', 'pixwell' ),
						'desc'    => esc_html__( 'Select sidebar position for the blog.', 'pixwell' ),
						'class'   => 'sidebar-select',
						'type'    => 'image_select',
						'options' => pixwell_add_settings_meta_sidebar_pos(),
						'default' => 'default'
					)
				),
			)
		)
	);

	return $pixwell_meta;
}
