<?php

if ( ! function_exists( 'pixwell_register_options_theme_styles' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_theme_styles() {

		return array(
			'id'    => 'pixwell_config_section_styling_global',
			'title' => esc_html__( 'Theme Design', 'pixwell' ),
            'icon'  => 'el el-idea',
			'desc'  => esc_html__( 'Manage theme styles. The settings below will apply to whole your website.', 'pixwell' ),
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_site_layout' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_site_layout() {

		return array(
			'id'         => 'pixwell_config_section_site_layout',
			'title'      => esc_html__( 'Site Layout', 'pixwell' ),
			'icon'       => 'el el-laptop',
			'subsection' => true,
			'desc'       => esc_html__( 'Select a layout for your website.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'          => 'site_layout',
					'type'        => 'select',
					'title'       => esc_html__( 'Site Layout', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select a layout for your website.', 'pixwell' ),
					'description' => esc_html__( 'This setting will apply to whole your website.', 'pixwell' ),
					'options'     => array(
						'0'        => esc_html__( 'Full Width', 'pixwell' ),
						'is-boxed' => esc_html__( 'Boxed', 'pixwell' )
					),
					'default'     => 0
				),
				array(
					'id'          => 'boxed_bg',
					'type'        => 'background',
					'transparent' => false,
					'title'       => esc_html__( 'Boxed - Site Background', 'pixwell' ),
					'subtitle'    => esc_html__( 'Site background with image, color...', 'pixwell' ),
					'description' => esc_html__( 'The settings only apply to the boxed layout.', 'pixwell' ),
					'default'     => array(
						'background-color'      => '#fafafa',
						'background-size'       => 'cover',
						'background-attachment' => 'fixed',
						'background-position'   => 'center center',
						'background-repeat'     => 'no-repeat'
					)
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_round_conner' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_round_conner() {

		return array(
			'id'         => 'pixwell_config_section_round_conner',
			'title'      => esc_html__( 'Round Corner', 'pixwell' ),
			'icon'       => 'el el-record',
			'subsection' => true,
			'desc'       => esc_html__( 'The small border style in featured images and other element whole the website.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'style_element',
					'title'    => esc_html__( 'Round Corner', 'pixwell' ),
					'subtitle' => esc_html__( 'Select an round corner style for your site elements.', 'pixwell' ),
					'type'     => 'select',
					'options'  => array(
						'none'      => esc_html__( 'Rectangle', 'pixwell' ),
						'round_all' => esc_html__( 'Rounded Corner', 'pixwell' ),
						'round'     => esc_html__( 'Rounded Corner without Featured', 'pixwell' ),
					),
					'default'  => 'none',
				),
			)
		);
	}
}
if ( ! function_exists( 'pixwell_register_options_design_gif' ) ) {
    /**
     * @return array
     */
    function pixwell_register_options_design_gif() {

        return array(
            'id'         => 'pixwell_config_section_gif_supported',
            'title'      => esc_html__( 'Featured GIF', 'pixwell' ),
            'icon'       => 'el el-photo',
            'desc'       => esc_html__( 'Prevent WordPress convert gif to a static image when uploading.', 'pixwell' ),
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'gif_support',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'GIF Supported', 'pixwell' ),
                    'subtitle' => esc_html__( 'Enable or disable GIF supported for your site.', 'pixwell' ),
                    'default'  => '1'
                ),
            )
        );
    }
}

if ( ! function_exists( 'pixwell_register_options_block_header' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_block_header() {

		return array(
			'id'         => 'pixwell_config_section_block_header',
			'title'      => esc_html__( 'Block Heading', 'pixwell' ),
			'icon'       => 'el el-minus',
			'subsection' => true,
			'desc'       => esc_html__( 'The global heading settings for blocks, widgets, archives.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'          => 'block_header_style',
					'title'       => esc_html__( 'Block Header Style', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select a style for the block and section header.', 'pixwell' ),
					'description' => esc_html__( 'The settings will apply to blocks which are build with Ruby Composer and Elementor.', 'pixwell' ),
					'type'        => 'select',
					'options'     => array(
						'dot' => esc_html__( '--Default-- (Dot)', 'pixwell' ),
						'1'   => esc_html__( 'Style 1 (Small Border)', 'pixwell' ),
						'2'   => esc_html__( 'Style 2 (Centered & Small Line)', 'pixwell' ),
						'3'   => esc_html__( 'Style 3 (Left No Border Radius)', 'pixwell' ),
						'4'   => esc_html__( 'Style 4 (Title with Background)', 'pixwell' ),
						'5'   => esc_html__( 'Style 5 (Centered and Bold Dot)', 'pixwell' ),
						'6'   => esc_html__( 'Style 6 (Left Title with Big Dot)', 'pixwell' ),
						'7'   => esc_html__( 'Style 7 (Left Title with Big Border)', 'pixwell' )
					),
					'default'     => 'dot',
				),
				array(
					'id'       => 'widget_header_style',
					'title'    => esc_html__( 'Sidebar Widget Header Style', 'pixwell' ),
					'subtitle' => esc_html__( 'The settings will apply to the header of the right sidebar and footer widgets.', 'pixwell' ),
					'type'     => 'select',
					'options'  => array(
						'1' => esc_html__( '--Default-- (Title Only)', 'pixwell' ),
						'2' => esc_html__( 'Style 2 (Centered)', 'pixwell' ),
						'3' => esc_html__( 'Style 3 (Background)', 'pixwell' )
					),
					'default'  => 1,
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_entry_category' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_entry_category() {

		return array(
			'id'         => 'pixwell_config_section_entry_category',
			'title'      => esc_html__( 'Entry Category', 'pixwell' ),
			'icon'       => 'el el-folder-open',
			'subsection' => true,
			'desc'       => esc_html__( 'The category icon and label display in the post listing.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'    => 'info_cat_global',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'These settings treated as a global setting. Individual category settings take priority over them.', 'pixwell' ),
				),
				array(
					'id'    => 'info_cat_individual',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'To edit styles and layout for individual category. Navigate to "Posts > Categories > Edit Category > Pixwell Category Options".', 'pixwell' ),
				),
				array(
					'id'       => 'style_cat_icon',
					'title'    => esc_html__( 'Category Style', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a style for the entry category to display in the post listing.', 'pixwell' ),
					'type'     => 'select',
					'options'  => array(
						'radius' => esc_html__( '-- Default -- (Square)', 'pixwell' ),
						'round'  => esc_html__( 'Rounded Corner', 'pixwell' ),
						'square' => esc_html__( 'Small Square', 'pixwell' ),
						'line'   => esc_html__( 'Underline Text', 'pixwell' ),
						'simple' => esc_html__( 'Text Only', 'pixwell' )
					),
					'default'  => 'radius',
				),
				array(
					'id'          => 'cat_icon_bg_color',
					'title'       => esc_html__( 'Highlight Color', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select a highlight color for the entry category to display in the post listing.', 'pixwell' ),
					'type'        => 'color',
					'transparent' => false,
					'default'     => '',
				),
				array(
					'id'          => 'cat_icon_text_color',
					'title'       => esc_html__( 'Text Color', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select a text color for the category icon.', 'pixwell' ),
					'type'        => 'color',
					'transparent' => false,
					'default'     => '',
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_design_tooltips' ) ) {
    function pixwell_register_options_design_tooltips() {

        return array(
            'id'         => 'pixwell_config_section_tooltips',
            'title'      => esc_html__( 'Tooltips', 'pixwell' ),
            'icon'       => 'el el-question-sign',
            'desc'       => esc_html__( 'Manage tooltips for the share on socials.', 'pixwell' ),
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'site_tooltips',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Tooltips', 'pixwell' ),
                    'subtitle' => esc_html__( 'Show tooltips when you mouse over elements.', 'pixwell' ),
                    'default'  => true
                ),
            )
        );
    }
}

if ( ! function_exists( 'pixwell_register_options_design_back_top' ) ) {
    function pixwell_register_options_design_back_top() {
        return array(
            'id'         => 'pixwell_config_section_back_top',
            'title'      => esc_html__( 'Back to Top', 'pixwell' ),
            'icon'       => 'el el-arrow-up',
            'desc'       => esc_html__( 'Manage the back to top button in the site.', 'pixwell' ),
            'subsection' => true,
            'fields'     => array(
                array(
                    'id'       => 'site_back_to_top',
                    'type'     => 'switch',
                    'title'    => esc_html__( 'Back to Top', 'pixwell' ),
                    'subtitle' => esc_html__( 'Show the back to top button at the bottom right.', 'pixwell' ),
                    'default'  => true
                ),
            )
        );
    }
}

if ( ! function_exists( 'pixwell_register_options_featured_image' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_featured_image() {

		return array(
			'id'         => 'pixwell_config_section_featured_image',
			'title'      => esc_html__( 'Featured Image', 'pixwell' ),
			'icon'       => 'el el-picture',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage styles and crop sizes for the post featured image to optimize your hosting disk space.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'    => 'info_size_regen',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => html_entity_decode( esc_html__( 'Run "REGENERATE THUMBNAILS" if you change the settings below. Refer <a href="//help.themeruby.com/pixwell/what-to-do-when-images-are-not-displaying-consistent-in-size/" target="_blank">this documentation</a> for further information.', 'pixwell' ) ),
				),
				array(
					'id'    => 'info_crop_size',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'WordPress will crop uploaded images to ensure your website use the the size for the layout. You can disable unused sizes here.', 'pixwell' ),
				),
				array(
					'id'    => 'info_module_size',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'Retina(2x) or full size of images will be loaded If a module cannot not find its defined crop size.', 'pixwell' ),
				),
				array(
					'id'       => 'pos_feat',
					'type'     => 'select',
					'title'    => esc_html__( 'Crop Position', 'pixwell' ),
					'subtitle' => esc_html__( 'Select position to crop the featured images. Recommend the top position for people images.', 'pixwell' ),
					'options'  => array(
						'center' => esc_html__( 'From The Center', 'pixwell' ),
						'top'    => esc_html__( 'From The Top', 'pixwell' ),
					),
					'default'  => 'center'
				),
				array(
					'id'       => 'feat_overlay',
					'type'     => 'switch',
					'title'    => esc_html__( 'Dark Overlay on Featured Image', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable overlay on the featured images.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_v1',
					'type'     => 'switch',
					'title'    => esc_html__( '370x250', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Grid 1, Overlay 2', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_v2',
					'type'     => 'switch',
					'title'    => esc_html__( '740x500', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Classic 1, Classic 2, List 1, List 6, Support retina for the size 370x250.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_v3',
					'type'     => 'switch',
					'title'    => esc_html__( '1110x750', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Overlay 1, Support retina for the size 740x500.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_v4',
					'type'     => 'switch',
					'title'    => esc_html__( '280x210', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Grid 2, Grid 4, Grid W1, List 2, List 3, List 4, Left Side Article, Deals, Ruby Newsletter', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_v5',
					'type'     => 'switch',
					'title'    => esc_html__( '560x420', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Overlay 5, support retina for the size 280x210.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_h1',
					'type'     => 'switch',
					'title'    => esc_html__( '400x450', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Grid 5, Grid 6, Overlay 3, Category List.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_h2',
					'type'     => 'switch',
					'title'    => esc_html__( '400x600', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Overlay 8, Mix Grid (Wrapper).', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_z1',
					'type'     => 'switch',
					'title'    => esc_html__( '450x0', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Masonry 1, Portfolio layout.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_z2',
					'type'     => 'switch',
					'title'    => esc_html__( '780x0', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Classic 2, Single Post Page, Mix Grid (Wrapper), support retina for the size 450x0.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'image_size_z3',
					'type'     => 'switch',
					'title'    => esc_html__( '1600x0', 'pixwell' ),
					'subtitle' => esc_html__( 'This image is used for modules: Overlay 4, Overlay 7, Overlay 9, Single Post Page (without sidebar, Fullwidth and Fullscreen), Gallery. Support retina for the size 780x0.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_entry_meta' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_entry_meta() {

		return array(
			'id'         => 'pixwell_config_section_entry_meta',
			'title'      => esc_html__( 'Entry Meta', 'pixwell' ),
			'icon'       => 'el el-adjust-alt',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage post entry meta for the blog post listing.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'    => 'info_post_view',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'The view meta requests the "Post Views Counter" plugin to run.', 'pixwell' ),
				),
				array(
					'id'     => 'section_start_style_meta',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Entry Meta', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'meta_date_icon',
					'title'    => esc_html__( 'Date Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Show a clock icon before the date entry meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => false,
				),
				array(
					'id'       => 'human_time',
					'title'    => esc_html__( 'Human Time Format', 'pixwell' ),
					'subtitle' => esc_html__( 'Show date in the human format ("ago").', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 0
				),
				array(
					'id'       => 'meta_author_icon',
					'title'    => esc_html__( 'Avatar Image', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the author avatar image before the author entry meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1,
				),
				array(
					'id'       => 'meta_comment_icon',
					'title'    => esc_html__( 'Comment Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the comment icon before the comment entry meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => false,
				),
				array(
					'id'       => 'meta_view_icon',
					'title'    => esc_html__( 'View Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Show an eye icon before the view entry meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => false,
				),
				array(
					'id'          => 'entry_meta_style',
					'title'       => esc_html__( 'Classic Border', 'pixwell' ),
					'subtitle'    => esc_html__( 'Show a border at the top of the post entry meta. ', 'pixwell' ),
					'description' => esc_html__( 'This setting only apply to the big list and classic layout.', 'pixwell' ),
					'type'        => 'select',
					'options'     => array(
						'0'      => esc_html__( '--Default--', 'pixwell' ),
						'border' => esc_html__( 'Top Border (Fashion Style)', 'pixwell' )
					),
					'default'     => 0,
				),
				array(
					'id'     => 'section_end_style_meta',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'       => 'section_start_meta_shop',
					'type'     => 'section',
					'class'    => 'ruby-section-start',
					'title'    => esc_html__( 'Shop The Post Meta', 'pixwell' ),
					'subtitle' => esc_html__( 'The settings will override the post entry meta.', 'pixwell' ),
					'indent'   => true
				),
				array(
					'id'       => 'meta_shop_post',
					'title'    => esc_html__( 'Shop the Post Meta', 'pixwell' ),
					'subtitle' => esc_html__( 'Display shop the post text with a icon', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1,
				),
				array(
					'id'     => 'section_end_meta_shop',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_read_time',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Read Time Meta', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'          => 'read_speed',
					'title'       => esc_html__( 'Reading Speed (Word per minute)', 'pixwell' ),
					'subtitle'    => esc_html__( 'Input a number of words per minute.', 'pixwell' ),
					'description' => esc_html__( 'Default is 130 words per minute.', 'pixwell' ),
					'type'        => 'text',
					'default'     => 130,
				),
				array(
					'id'       => 'meta_read_icon',
					'title'    => esc_html__( 'Read Meta Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the clock icon before the read time meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => false,
				),
				array(
					'id'     => 'section_end_read_time',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_post_format' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_post_format() {

		return array(
			'id'         => 'pixwell_config_section_post_format',
			'title'      => esc_html__( 'Post Format', 'pixwell' ),
			'icon'       => 'el el-play',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage post format icons for displaying on the post thumbnails.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'post_icon_video',
					'title'    => esc_html__( 'Video Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the video icon.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1
				),
				array(
					'id'       => 'post_icon_gallery',
					'title'    => esc_html__( 'Gallery Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the gallery icon.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 0
				),
				array(
					'id'       => 'post_icon_audio',
					'title'    => esc_html__( 'Audio Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the audio icon.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 0
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_custom_meta' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_custom_meta() {

		return array(
			'id'         => 'pixwell_config_section_custom_meta',
			'title'      => esc_html__( 'Custom Meta', 'pixwell' ),
			'icon'       => 'el el-asterisk',
			'subsection' => true,
			'desc'       => esc_html__( 'A new meta will appear after the entry category.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'meta_custom',
					'title'    => esc_html__( 'Custom Entry Meta', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the custom meta.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1,
				),
				array(
					'id'          => 'meta_custom_text',
					'title'       => esc_html__( 'Meta Label', 'pixwell' ),
					'subtitle'    => esc_html__( 'Input the label for this meta.', 'pixwell' ),
					'description' => esc_html__( 'This string will be combined with a value in the post settings to display.', 'pixwell' ),
					'type'        => 'text',
					'default'     => ''
				),
				array(
					'id'          => 'meta_custom_icon',
					'title'       => esc_html__( 'Meta Icon ClassName', 'pixwell' ),
					'subtitle'    => esc_html__( 'Input your custom CSS icon classname to display at the beginning of the meta.', 'pixwell' ),
					'description' => esc_html__( 'Find icons here: https://icons.themeruby.com/pixwell/', 'pixwell' ),
					'placeholder' => 'rbi-fish-eye',
					'type'        => 'text',
					'default'     => 'rbi-fish-eye',
				),
				array(
					'id'       => 'meta_custom_pos',
					'title'    => esc_html__( 'Label Position', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a position for the meta label.', 'pixwell' ),
					'type'     => 'select',
					'options'  => array(
						'end'   => esc_html__( 'Suffixes (at the end)', 'pixwell' ),
						'begin' => esc_html__( 'Prefix (at the begin)', 'pixwell' ),

					),
					'default'  => 'end',
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_slider' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_slider() {

		return array(
			'id'         => 'pixwell_config_section_slider',
			'title'      => esc_html__( 'Slider Animation', 'pixwell' ),
			'icon'       => 'el el-resize-horizontal',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage animation for the post sliders and carousels.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'slider_play',
					'type'     => 'switch',
					'title'    => esc_html__( 'Autoplay', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable autoplay next slides.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'          => 'slider_speed',
					'type'        => 'text',
					'validate'    => 'numeric',
					'placeholder' => '5500',
					'title'       => esc_html__( 'Auto Play Speed', 'pixwell' ),
					'subtitle'    => esc_html__( 'The time delay to slide to the next slider.', 'pixwell' ),
					'description' => esc_html__( 'The default value is 5500 (milliseconds).', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'       => 'slider_dot',
					'type'     => 'switch',
					'title'    => esc_html__( 'Slider Dot', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable slider dot in your website.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'          => 'slider_animation',
					'type'        => 'select',
					'title'       => esc_html__( 'Slide Animation', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select a transform animation for sliders.', 'pixwell' ),
					'description' => esc_html__( 'This setting will not apply to the carousel blocks.', 'pixwell' ),
					'options'     => array(
						'0' => esc_html__( 'Slide', 'pixwell' ),
						'1' => esc_html__( 'Fade', 'pixwell' ),
					),
					'default'     => 0
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_read_more' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_read_more() {

		return array(
			'id'         => 'pixwell_config_section_read_more',
			'title'      => esc_html__( 'Read More', 'pixwell' ),
			'icon'       => 'el el-arrow-right',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage the read more styles for the post listing.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'    => 'info_read_more_pagespeed',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'Enabling the read more text may cause SEO issues with the pagespeed test tool.', 'pixwell' ),
				),
				array(
					'id'    => 'info_read_more',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'The read more button can be enabled in the "Modules Design" settings.', 'pixwell' ),
				),
				array(
					'id'    => 'info_read_more_text',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'Navigate to "Theme Translation > Read More Text" to edit the text.', 'pixwell' ),
				),
				array(
					'id'       => 'readmore_icon',
					'title'    => esc_html__( 'Arrow Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Show arrow icon after the read more text.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1,
				),
				array(
					'id'       => 'readmore_mobile',
					'title'    => esc_html__( 'Hide Read More on Mobile', 'pixwell' ),
					'subtitle' => esc_html__( 'Hide the read more link on the mobile devices.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 0,
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_excerpt' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_excerpt() {

		return array(
			'id'         => 'pixwell_config_section_excerpt',
			'title'      => esc_html__( 'Post Excerpt', 'pixwell' ),
			'icon'       => 'el el-pencil',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage the post excerpt.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'excerpt_mobile',
					'title'    => esc_html__( 'Hide Excerpt on Mobile', 'pixwell' ),
					'subtitle' => esc_html__( 'Hide post excerpt on mobile devices.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => 1,
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_pagination' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_pagination() {

		return array(
			'id'         => 'pixwell_config_section_pagination',
			'title'      => esc_html__( 'Pagination', 'pixwell' ),
			'icon'       => 'el el-minus',
			'subsection' => true,
			'desc'       => esc_html__( 'Manage style for the blog pagination.', 'pixwell' ),
			'fields'     => array(
				array(
					'id'       => 'pagination_layout',
					'type'     => 'select',
					'title'    => esc_html__( 'Pagination Style', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a button style for the blog pagination.', 'pixwell' ),
					'options'  => array(
						'light' => esc_html__( 'Light Background', 'pixwell' ),
						'dark'  => esc_html__( 'Dark Background', 'pixwell' ),
					),
					'default'  => 'light'
				),
			)
		);
	}
}
