<?php
if ( ! function_exists( 'pixwell_register_options_post_types' ) ) {
	function pixwell_register_options_post_types() {

		return array(
			'id'    => 'pixwell_config_section_post_types',
			'title' => esc_html__( 'Post Types', 'pixwell' ),
			'icon'  => 'dashicons-before dashicons-archive rb-tops-icon',
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_portfolio' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_portfolio() {

		return array(
			'id'         => 'pixwell_config_section_portfolio',
			'title'      => esc_html__( 'Portfolio', 'pixwell' ),
			'desc'       => esc_html__( 'Manage the portfolio post type.', 'pixwell' ),
			'icon'       => 'el el-briefcase',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_portfolio_permalink',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Permalinks', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'          => 'portfolio_permalink',
					'type'        => 'text',
					'title'       => esc_html__( 'Single Slug', 'pixwell' ),
					'placeholder' => 'portfolio',
					'subtitle'    => esc_html__( 'Input a custom slug for the single portfolio.', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'          => 'portfolio_cat_permalink',
					'type'        => 'text',
					'title'       => esc_html__( 'Category Slug', 'pixwell' ),
					'placeholder' => 'portfolio-category',
					'subtitle'    => esc_html__( 'Input a custom slug for the category portfolio.', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'     => 'section_end_portfolio_permalink',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_portfolio_archive',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Portfolio Category', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'portfolio_archive_layout',
					'type'     => 'select',
					'title'    => esc_html__( 'Portfolio Layout', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a listing layout to display in categories and archive page.', 'pixwell' ),
					'options'  => array(
						'masonry_3' => esc_html__( 'Masonry 3 Columns', 'pixwell' ),
						'masonry_4' => esc_html__( 'Masonry 4 Columns', 'pixwell' ),
					),
					'default'  => 'masonry_3'
				),
				array(
					'id'          => 'portfolio_posts_per_page',
					'type'        => 'text',
					'title'       => esc_html__( 'Posts per Page', 'pixwell' ),
					'subtitle'    => esc_html__( 'Input number of posts per page.', 'pixwell' ),
					'description' => esc_html__( 'This setting will override the setting "Settings > Reading > Blog pages show at most.', 'pixwell' ),
					'class'       => 'small-text',
					'validate'    => 'numeric'
				),
				array(
					'id'     => 'section_end_portfolio_archive',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_portfolio_single',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Single Portfolio', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'portfolio_info_header',
					'type'     => 'text',
					'title'    => esc_html__( 'Information Title', 'pixwell' ),
					'subtitle' => esc_html__( 'Input a title to display at the top of the portfolio information section.', 'pixwell' ),
					'default'  => esc_html__( 'Info', 'pixwell' )
				),
				array(
					'id'       => 'portfolio_nav',
					'type'     => 'switch',
					'title'    => esc_html__( 'Next/Prev Navigation', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable NEXT/PREV navigation at the bottom of single portfolio.', 'pixwell' ),
					'default'  => 1
				),
				array(
					'id'       => 'portfolio_same_cat',
					'type'     => 'switch',
					'title'    => esc_html__( 'Next/Prev Navigation - Same Categories', 'pixwell' ),
					'subtitle' => esc_html__( 'Only display same categories.', 'pixwell' ),
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_grid_link',
					'type'     => 'switch',
					'title'    => esc_html__( 'Center Grid Link', 'pixwell' ),
					'subtitle' => esc_html__( 'Display the center grid link.', 'pixwell' ),
					'default'  => 1
				),
				array(
					'id'     => 'section_end_portfolio_single',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_portfolio_share',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Share on Socials', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'portfolio_share',
					'type'     => 'switch',
					'title'    => esc_html__( 'Share on Socials', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the sharing bar, This section will display below the portfolio.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'portfolio_share_facebook',
					'type'     => 'switch',
					'title'    => esc_html__( 'Facebook', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Facebook.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'portfolio_share_twitter',
					'type'     => 'switch',
					'title'    => esc_html__( 'Twitter', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Twitter.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'portfolio_share_pinterest',
					'type'     => 'switch',
					'title'    => esc_html__( 'Pinterest', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Pinterest.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'portfolio_share_whatsapp',
					'type'     => 'switch',
					'title'    => esc_html__( 'WhatsApp', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on WhatsApp.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_linkedin',
					'type'     => 'switch',
					'title'    => esc_html__( 'LinkedIn', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on LinkedIn.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_tumblr',
					'type'     => 'switch',
					'title'    => esc_html__( 'Tumblr', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Tumblr.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_reddit',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reddit', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Reddit.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_vk',
					'type'     => 'switch',
					'title'    => esc_html__( 'Vkontakte', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Vkontakte.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_telegram',
					'type'     => 'switch',
					'title'    => esc_html__( 'Telegram', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Telegram.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'portfolio_share_email',
					'type'     => 'switch',
					'title'    => esc_html__( 'Email', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Email.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_portfolio_share',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_portfolio_breadcrumb',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Breadcrumb', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'portfolio_breadcrumb',
					'type'     => 'switch',
					'title'    => esc_html__( 'Portfolio Breadcrumb', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the breadcrumb.', 'pixwell' ),
					'default'  => 0
				),
				array(
					'id'     => 'section_end_portfolio_breadcrumb',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_gallery' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_gallery() {

		return array(
			'id'         => 'pixwell_config_section_gallery',
			'title'      => esc_html__( 'Gallery', 'pixwell' ),
			'desc'       => esc_html__( 'Manage the gallery post type.', 'pixwell' ),
			'icon'       => 'el el-camera',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_gallery_permalink',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Permalinks', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'          => 'gallery_permalink',
					'type'        => 'text',
					'title'       => esc_html__( 'Single Slug', 'pixwell' ),
					'placeholder' => 'gallery',
					'subtitle'    => esc_html__( 'Input a custom slug for the single gallery.', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'          => 'gallery_cat_permalink',
					'type'        => 'text',
					'title'       => esc_html__( 'Category Slug', 'pixwell' ),
					'placeholder' => 'gallery-category',
					'subtitle'    => esc_html__( 'Input a custom slug for the category gallery.', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'     => 'section_end_gallery_permalink',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_gallery_share',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Share on Socials', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'gallery_share',
					'type'     => 'switch',
					'title'    => esc_html__( 'Share on Socials', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the sharing bar, This section will display below the gallery.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'gallery_share_facebook',
					'type'     => 'switch',
					'title'    => esc_html__( 'Facebook', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Facebook.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'gallery_share_twitter',
					'type'     => 'switch',
					'title'    => esc_html__( 'Twitter', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Twitter.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'gallery_share_pinterest',
					'type'     => 'switch',
					'title'    => esc_html__( 'Pinterest', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Pinterest.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'gallery_share_whatsapp',
					'type'     => 'switch',
					'title'    => esc_html__( 'WhatsApp', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on WhatsApp.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_linkedin',
					'type'     => 'switch',
					'title'    => esc_html__( 'LinkedIn', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on LinkedIn.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_tumblr',
					'type'     => 'switch',
					'title'    => esc_html__( 'Tumblr', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Tumblr.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_reddit',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reddit', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Reddit.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_vk',
					'type'     => 'switch',
					'title'    => esc_html__( 'Vkontakte', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Vkontakte.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_telegram',
					'type'     => 'switch',
					'title'    => esc_html__( 'Telegram', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Telegram.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'gallery_share_email',
					'type'     => 'switch',
					'title'    => esc_html__( 'Email', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Email.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_gallery_share',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_deal' ) ) {
	/**
	 * @return array|null
	 */
	function pixwell_register_options_deal() {

		if ( ! class_exists( 'rb_deal_core' ) ) {
			return null;
		}

		return array(
			'id'         => 'pixwell_config_section_deal',
			'title'      => esc_html__( 'Deal Coupon', 'pixwell' ),
			'desc'       => esc_html__( 'Manage for the deal post type.', 'pixwell' ),
			'icon'       => 'el el-bullhorn',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'          => 'card_color',
					'title'       => esc_html__( 'Card Color', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select color for the card display on the deal featured image. Default is #4ca695.', 'pixwell' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
				array(
					'id'          => 'coupon_color',
					'title'       => esc_html__( 'Coupon Color', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select color for the coupon display on the deal featured image. Default is #826abc.', 'pixwell' ),
					'type'        => 'color',
					'transparent' => false,
					'validate'    => 'color',
				),
			)
		);
	}
}