<?php

if ( ! function_exists( 'pixwell_register_options_single_post' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post() {

		return array(
			'title' => esc_html__( 'Single Post', 'pixwell' ),
			'id'    => 'pixwell_config_section_single_post',
			'desc'  => esc_html__( 'Select options for the single post, Options below will apply to all single post pages.', 'pixwell' ),
			'icon'  => 'el el-file',
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_post_styles' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post_styles() {

		return array(
			'title'      => esc_html__( 'Styles & Design', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_styles',
			'desc'       => esc_html__( 'Manage styles & layout for the single post.', 'pixwell' ),
			'icon'       => 'el el-adjust-alt',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'    => 'info_single_post_meta_global',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'The settings are treated as a global setting. Individual post settings take priority over them.', 'pixwell' ),
				),
				array(
					'id'    => 'info_single_post_settings',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'Navigate to "Post > Edit Post > Pixwell Post Options" to change settings for each post.', 'pixwell' ),
				),
				array(
					'id'     => 'section_start_single_entry_category',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Entry Category', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_cat_info',
					'type'     => 'switch',
					'title'    => esc_html__( 'Category Icon', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable entry category icon.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'          => 'single_cat_primary',
					'type'        => 'switch',
					'title'       => esc_html__( 'Primary Category', 'pixwell' ),
					'subtitle'    => esc_html__( 'Only show the primary category in the single post.', 'pixwell' ),
					'description' => esc_html__( 'To set a primary category for a post, navigate to "Post > Edit Post > Pixwell Post Options > General > Primary Category".', 'pixwell' ),
					'switch'      => true,
					'default'     => 0
				),
				array(
					'id'     => 'section_end_single_entry_category',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_single_meta_info',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Entry Meta', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_entry_meta',
					'type'     => 'sorter',
					'title'    => esc_html__( 'Entry Meta Bar Manager', 'pixwell' ),
					'subtitle' => esc_html__( 'Sort by how you want post entry meta to appear.', 'pixwell' ),
					'options'  => array(
						'enabled'  => array(
							'author' => esc_html__( 'Author', 'pixwell' ),
							'update'  => esc_html__( 'Last Updated', 'pixwell' ),
						),
						'disabled' => array(
							'date'   => esc_html__( 'Date', 'pixwell' ),
							'cat'     => esc_html__( 'Category', 'pixwell' ),
							'tag'     => esc_html__( 'Tags', 'pixwell' ),
							'view'    => esc_html__( 'View', 'pixwell' ),
							'comment' => esc_html__( 'Comment', 'pixwell' ),
							'read'    => esc_html__( 'Reading Time', 'pixwell' ),
							'custom'  => esc_html__( 'Custom', 'pixwell' )
						)
					),
				),
				array(
					'id'       => 'single_post_updated_meta',
					'type'     => 'switch',
					'title'    => esc_html__( 'Last Updated Meta', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the last updated meta info.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'single_post_custom_info',
					'type'     => 'switch',
					'title'    => esc_html__( 'Custom Meta', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the custom meta.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_avatar',
					'type'     => 'switch',
					'title'    => esc_html__( 'Avatar Image', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the author avatar image before the author entry meta.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_author_meta_label',
					'type'     => 'switch',
					'title'    => esc_html__( 'Author Label', 'pixwell' ),
					'subtitle' => esc_html__( 'Show the "By" string before the author meta.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'     => 'section_end_single_meta_info',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_single_featured_image',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Featured Image', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_feat_size',
					'type'     => 'select',
					'title'    => esc_html__( 'Crop Size', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a crop size for the feature image to disply in the single post page.', 'pixwell' ),
					'options'  => array(
						'full' => esc_html__( 'Full Size', 'pixwell' ),
						'crop' => esc_html__( 'Crop Size', 'pixwell' )
					),
					'default'  => 'full',
				),
				array(
					'id'       => 'single_post_parallax',
					'type'     => 'switch',
					'title'    => esc_html__( 'Parallax Animation', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable parallax animation when scrolling. This option will affect Full Wide and Full Screen layouts.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_single_featured_image',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_single_video',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Post Video', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_video_autoplay',
					'type'     => 'switch',
					'title'    => esc_html__( 'Video Autoplay', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable autoplay post video format.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_single_featured_video',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_single_gallery',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Post Gallery', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_gallery_layout',
					'type'     => 'select',
					'title'    => esc_html__( 'Gallery Layout', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a default layout for gallery post format.', 'pixwell' ),
					'options'  => array(
						'slide' => esc_html__( 'Slider', 'pixwell' ),
						'list'  => esc_html__( 'List Images', 'pixwell' ),
						'grid'  => esc_html__( 'Small Grid', 'pixwell' )
					),
					'default'  => 'slide'
				),
				array(
					'id'     => 'section_end_single_gallery',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				)
			),
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_post_layout' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post_layout() {

		return array(
			'title'      => esc_html__( 'Single Layout', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_layout',
			'desc'       => esc_html__( 'Manage layout for the single post.', 'pixwell' ),
			'icon'       => 'el el-laptop',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'    => 'info_single_post_layout_global',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'The settings are treated as a global setting. Individual post settings take priority over them.', 'pixwell' ),
				),
				array(
					'id'    => 'info_single_layout_featured',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'The settings below is treated as a global settings. Other position settings take priority over them.', 'pixwell' ),
				),
				array(
					'id'    => 'info_single_layout_featured',
					'type'  => 'info',
					'style' => 'warning',
					'desc'  => esc_html__( 'The layout automatically rollback to the "Classic" if its featured image isn\'t set.', 'pixwell' ),
				),
				array(
					'id'    => 'info_single_layout_edit',
					'type'  => 'info',
					'style' => 'info',
					'desc'  => esc_html__( 'Navigate to "Post > Edit Post > Pixwell Post Options" to change settings for each post.', 'pixwell' ),
				),
				array(
					'id'     => 'section_start_single_post_layout',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Layout', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_layout',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Single Layout', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a layout for the single post.', 'pixwell' ),
					'desc'     => esc_html__( 'Some layouts requests FEATURED IMAGE to work.', 'pixwell' ),
					'options'  => pixwell_add_settings_single_layouts(),
					'default'  => '1',
				),
				array(
					'id'          => 'single_post_header_align',
					'type'        => 'switch',
					'title'       => esc_html__( 'Layout Classic - Centered Header', 'pixwell' ),
					'subtitle'    => esc_html__( 'Align center the single post header.', 'pixwell' ),
					'description' => esc_html__( 'This setting only apply to the classic layouts.', 'pixwell' ),
					'default'     => '0',
				),
				array(
					'id'          => 'single_podcast_layout',
					'type'        => 'select',
					'title'       => esc_html__( 'Podcast Layout', 'pixwell' ),
					'subtitle'    => esc_html__( 'Show podcast layout for the audio post format.', 'pixwell' ),
					'description' => esc_html__( 'This setting only apply to the audio post format.', 'pixwell' ),
					'options'     => array(
						'1' => esc_html__( 'Default Layout', 'pixwell' ),
						'2' => esc_html__( 'Enable Single Podcast', 'pixwell' ),
					),
					'default'     => '1',
				),
				array(
					'id'          => 'single_podcast_bg_color',
					'type'        => 'color',
					'transparent' => false,
					'title'       => esc_html__( 'Top - Background Color', 'pixwell' ),
					'subtitle'    => esc_html__( 'Select color background for the single podcast layout.', 'pixwell' ),
					'default'     => ''
				),
				array(
					'id'     => 'section_end_single_post_layout',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_single_post_sidebar',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Sidebar', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_sidebar_name',
					'type'     => 'select',
					'title'    => esc_html__( 'Assign a Sidebar', 'pixwell' ),
					'subtitle' => esc_html__( 'Assign a sidebar for the single post.', 'pixwell' ),
					'options'  => pixwell_add_settings_sidebar_name(),
					'default'  => 'pixwell_sidebar_default'
				),
				array(
					'id'       => 'single_post_sidebar_pos',
					'type'     => 'image_select',
					'title'    => esc_html__( 'Sidebar Position', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a sidebar position for the single post.', 'pixwell' ),
					'options'  => pixwell_add_settings_sidebar_pos(),
					'default'  => 'default'
				),
				array(
					'id'     => 'section_end_single_post_layout',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_post_section' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post_section() {

		return array(
			'title'      => esc_html__( 'Single Sections', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_section',
			'desc'       => esc_html__( 'Select options for sections in the single post.', 'pixwell' ),
			'icon'       => 'el el-th-list',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_single_section_footer',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Footer Content Area', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_tag',
					'type'     => 'switch',
					'title'    => esc_html__( 'Post Tags at The Bottom', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the tags bar at the bottom of the post content.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_source',
					'type'     => 'switch',
					'title'    => esc_html__( 'Source Information', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the source bar at the bottom of the post content.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_via',
					'type'     => 'switch',
					'title'    => esc_html__( 'Via Information', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the via bar at the bottom of the post content.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_like',
					'type'     => 'switch',
					'title'    => esc_html__( 'LIKE/TWEET Buttons', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable post like/tweet buttons at the bottom post content.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'     => 'section_end_start_single_section_footer',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'       => 'section_start_single_box',
					'type'     => 'section',
					'class'    => 'ruby-section-start',
					'title'    => esc_html__( 'Elements', 'pixwell' ),
					'subtitle' => esc_html__( 'The author card box requests author information. Navigate to "Users > Your profiles" to fill full information.', 'pixwell' ),
					'indent'   => true
				),
				array(
					'id'       => 'single_post_author',
					'type'     => 'switch',
					'title'    => esc_html__( 'Author Card', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the author card in the single post.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_p_multi_author',
					'type'     => 'switch',
					'title'    => esc_html__( 'Multi Author Card', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the multi author cards in the single post.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_navigation',
					'type'     => 'switch',
					'title'    => esc_html__( 'Next/Prev Articles', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the next/previous link navigation in the single post.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_comment_btn',
					'type'     => 'switch',
					'title'    => esc_html__( 'Show/Hide Comment Button', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable comment box buttons in the single post pages.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'     => 'section_end_single_box',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_post_share' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post_share() {

		return array(
			'title'      => esc_html__( 'Share on Socials', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_share',
			'desc'       => esc_html__( 'Manage the share on socials sections for the single post.', 'pixwell' ),
			'icon'       => 'el el-share',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_single_post_total_shares',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Total Counter', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'          => 'total_share',
					'type'        => 'switch',
					'title'       => esc_html__( 'Total Counter', 'pixwell' ),
					'subtitle'    => esc_html__( 'Show the total shares value.', 'pixwell' ),
					'description' => esc_html__( 'The theme will calculate shares data from Facebook and Pinterest.', 'pixwell' ),
					'switch'      => true,
					'default'     => 0
				),
				array(
					'id'     => 'section_end_single_post_total_shares',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'       => 'section_start_single_post_social_top',
					'type'     => 'section',
					'class'    => 'ruby-section-start',
					'title'    => esc_html__( 'for The Top Area', 'pixwell' ),
					'subtitle' => esc_html__( 'The section will appear at the top of the single post, below the single entry meta info.', 'pixwell' ),
					'indent'   => true
				),
				array(
					'id'       => 'share_top',
					'type'     => 'switch',
					'title'    => esc_html__( 'Share Bar', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable top share section.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_facebook',
					'type'     => 'switch',
					'title'    => esc_html__( 'Facebook', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Facebook.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_top_twitter',
					'type'     => 'switch',
					'title'    => esc_html__( 'Twitter', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Twitter.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_top_pinterest',
					'type'     => 'switch',
					'title'    => esc_html__( 'Pinterest', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Pinterest.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_top_whatsapp',
					'type'     => 'switch',
					'title'    => esc_html__( 'WhatsApp', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on WhatsApp.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_linkedin',
					'type'     => 'switch',
					'title'    => esc_html__( 'LinkedIn', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on LinkedIn.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_tumblr',
					'type'     => 'switch',
					'title'    => esc_html__( 'Tumblr', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Tumblr.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_reddit',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reddit', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Reddit.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_vk',
					'type'     => 'switch',
					'title'    => esc_html__( 'Vkontakte', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Vkontakte.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_telegram',
					'type'     => 'switch',
					'title'    => esc_html__( 'Telegram', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Telegram.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_top_email',
					'type'     => 'switch',
					'title'    => esc_html__( 'Email', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Email.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_single_post_social_top',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'       => 'section_start_single_post_social_bottom',
					'type'     => 'section',
					'class'    => 'ruby-section-start',
					'title'    => esc_html__( 'for The Bottom Content', 'pixwell' ),
					'subtitle' => esc_html__( 'The section will appear at the bottom of the single post content.', 'pixwell' ),
					'indent'   => true
				),
				array(
					'id'       => 'share_bottom',
					'type'     => 'switch',
					'title'    => esc_html__( 'Share Bar', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the bottom share bar.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_bottom_facebook',
					'type'     => 'switch',
					'title'    => esc_html__( 'Facebook', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Facebook.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_bottom_twitter',
					'type'     => 'switch',
					'title'    => esc_html__( 'Twitter', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Twitter.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_bottom_pinterest',
					'type'     => 'switch',
					'title'    => esc_html__( 'Pinterest', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Pinterest.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_bottom_whatsapp',
					'type'     => 'switch',
					'title'    => esc_html__( 'WhatsApp', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on WhatsApp.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_linkedin',
					'type'     => 'switch',
					'title'    => esc_html__( 'LinkedIn', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on LinkedIn.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_tumblr',
					'type'     => 'switch',
					'title'    => esc_html__( 'Tumblr', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Tumblr.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_reddit',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reddit', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Reddit.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_vk',
					'type'     => 'switch',
					'title'    => esc_html__( 'Vkontakte', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Vkontakte.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_telegram',
					'type'     => 'switch',
					'title'    => esc_html__( 'Telegram', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Telegram.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_bottom_email',
					'type'     => 'switch',
					'title'    => esc_html__( 'Email', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Email.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_single_post_social_bottom',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

/** related section */
if ( ! function_exists( 'pixwell_register_options_single_post_related' ) ) {
	function pixwell_register_options_single_post_related() {

		return array(
			'title'      => esc_html__( 'Related Section', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_related',
			'desc'       => esc_html__( 'Manage the related section.', 'pixwell' ),
			'icon'       => 'el el-paper-clip ',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'       => 'single_post_related',
					'type'     => 'switch',
					'title'    => esc_html__( 'Related Section', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the related posts.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_related_layout',
					'type'     => 'select',
					'required' => array( 'single_post_related', '=', '1' ),
					'title'    => esc_html__( 'Blog Layout', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a layout for the posts listing.', 'pixwell' ),
					'options'  => array(
						'fw_grid_1' => esc_html__( 'FullWidth Grid 1', 'pixwell' ),
						'fw_grid_2' => esc_html__( 'FullWidth Grid 2', 'pixwell' ),
						'fw_list_1' => esc_html__( 'FullWidth List 1', 'pixwell' ),
						'fw_list_2' => esc_html__( 'FullWidth List 2', 'pixwell' ),
					),
					'default'  => 'fw_grid_2'
				),
				array(
					'id'       => 'single_post_related_where',
					'type'     => 'select',
					'required' => array( 'single_post_related', '=', '1' ),
					'title'    => esc_html__( 'Filter Type', 'pixwell' ),
					'subtitle' => esc_html__( 'Where to get the posts to show.', 'pixwell' ),
					'options'  => array(
						'all' => esc_html__( 'Same Tags & Categories', 'pixwell' ),
						'tag' => esc_html__( 'Same Tags', 'pixwell' ),
						'cat' => esc_html__( 'Same Categories', 'pixwell' ),
					),
					'default'  => 'all'
				),
				array(
					'id'       => 'single_post_related_total',
					'type'     => 'text',
					'class'    => 'small-text',
					'validate' => 'numeric',
					'required' => array( 'single_post_related', '=', '1' ),
					'title'    => esc_html__( 'Number of Posts', 'pixwell' ),
					'subtitle' => esc_html__( 'Select number of posts to show at once.', 'pixwell' ),
					'default'  => 4
				),
				array(
					'id'       => 'single_post_related_pagination',
					'title'    => esc_html__( 'Pagination Type', 'pixwell' ),
					'subtitle' => esc_html__( 'Select a type for the blog pagination.', 'pixwell' ),
					'type'     => 'select',
					'required' => array( 'single_post_related', '=', '1' ),
					'options'  => array(
						'0'        => esc_html__( 'Disabled', 'pixwell' ),
						'loadmore' => esc_html__( 'Load More', 'pixwell' ),
					),
					'default'  => '0'
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_post_left' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_post_left() {

		return array(
			'title'      => esc_html__( 'Left Content', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_left_section',
			'desc'       => esc_html__( 'A floating section at the left of the post content.', 'pixwell' ),
			'icon'       => 'el el-braille',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_single_left_section',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'General', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_left_section',
					'title'    => esc_html__( 'Left Content Section', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the left content section.', 'pixwell' ),
					'type'     => 'switch',
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_left',
					'type'     => 'switch',
					'title'    => esc_html__( 'Left Share Bar', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the share on socials bar.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'single_post_left_article',
					'title'    => esc_html__( 'Recommended Article', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable a most recommended article.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => '1'
				),
				array(
					'id'     => 'section_end_single_left_section',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'       => 'section_start_single_left_socials',
					'title'    => esc_html__( 'Share on Socials', 'pixwell' ),
					'subtitle' => array(
						esc_html__( 'The settings below requests "Left Share Bar" is enabled to work.', 'pixwell' ),
						esc_html__( 'The settings below will apply to the single left content section.', 'pixwell' )
					),
					'type'     => 'section',
					'class'    => 'ruby-section-start',
					'indent'   => true
				),
				array(
					'id'       => 'share_left_facebook',
					'type'     => 'switch',
					'title'    => esc_html__( 'Facebook', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Facebook.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_left_twitter',
					'type'     => 'switch',
					'title'    => esc_html__( 'Twitter', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Twitter.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_left_pinterest',
					'type'     => 'switch',
					'title'    => esc_html__( 'Pinterest', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Pinterest.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'share_left_whatsapp',
					'type'     => 'switch',
					'title'    => esc_html__( 'WhatsApp', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on WhatsApp.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_linkedin',
					'type'     => 'switch',
					'title'    => esc_html__( 'LinkedIn', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on LinkedIn.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_tumblr',
					'type'     => 'switch',
					'title'    => esc_html__( 'Tumblr', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Tumblr.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_reddit',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reddit', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Reddit.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_vk',
					'type'     => 'switch',
					'title'    => esc_html__( 'Vkontakte', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Vkontakte.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_telegram',
					'type'     => 'switch',
					'title'    => esc_html__( 'Telegram', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Telegram.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'share_left_email',
					'type'     => 'switch',
					'title'    => esc_html__( 'Email', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable share on Email.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_single_left_socials',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				),
			)
		);
	}
}

/** infinite load next */
if ( ! function_exists( 'pixwell_register_options_single_next_post' ) ) {
	function pixwell_register_options_single_next_post() {

		return array(
			'id'         => 'pixwell_config_section_single_next',
			'title'      => esc_html__( 'Infinite Next Posts', 'pixwell' ),
			'desc'       => esc_html__( 'Increase your pageviews by engaging the site viewers to keep reading your content.', 'pixwell' ),
			'icon'       => 'el el-repeat',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'       => 'ajax_next_post',
					'type'     => 'switch',
					'title'    => esc_html__( 'Next Posts', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the load next posts feature.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'ajax_next_cat',
					'type'     => 'switch',
					'title'    => esc_html__( 'Same Category', 'pixwell' ),
					'subtitle' => esc_html__( 'Only show posts have the same category with the current post.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'ajax_next_related',
					'type'     => 'select',
					'title'    => esc_html__( 'Post Related', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the related section for the next posts.', 'pixwell' ),
					'options'  => array(
						'0' => esc_html__( '-Disable-', 'pixwell' ),
						'1' => esc_html__( 'Enable', 'pixwell' )
					),
					'default'  => '0'
				),
				array(
					'id'          => 'ajax_next_sidebar_name',
					'type'        => 'select',
					'title'       => esc_html__( 'Assign a Sidebar', 'pixwell' ),
					'subtitle'    => esc_html__( 'Assign a custom sidebar for the post next.', 'pixwell' ),
					'description' => esc_html__( 'we recommended to use a simple or only ad sidebar.', 'pixwell' ),
					'options'     => pixwell_add_settings_sidebar_name(),
					'default'     => 'pixwell_sidebar_default'
				),
				array(
					'id'       => 'ajax_next_hide_sidebar',
					'type'     => 'switch',
					'title'    => esc_html__( 'Hide Sidebar on Mobile', 'pixwell' ),
					'subtitle' => esc_html__( 'Hide sidebars on mobile when load next posts.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_single_review' ) ) {
	/**
	 * @return array
	 */
	function pixwell_register_options_single_review() {

		return array(
			'title'      => esc_html__( 'Post Review', 'pixwell' ),
			'id'         => 'pixwell_config_section_single_post_review',
			'desc'       => esc_html__( 'Select options for the post review.', 'pixwell' ),
			'icon'       => 'el el-star',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'       => 'review_users',
					'title'    => esc_html__( 'Users Review', 'pixwell' ),
					'subtitle' => esc_html__( 'Replace the comment box with a review box for the post review.', 'pixwell' ),
					'type'     => 'switch',
					'default'  => '0'
				)
			)
		);
	}
}

if ( ! function_exists( 'pixwell_register_options_reaction' ) ) {
	function pixwell_register_options_reaction() {

		return array(
			'id'         => 'pixwell_theme_ops_section_reaction',
			'title'      => esc_html__( 'Post Reactions', 'pixwell' ),
			'desc'       => esc_html__( 'Manage the reactions.', 'pixwell' ),
			'icon'       => 'el el-smiley',
			'subsection' => true,
			'fields'     => array(
				array(
					'id'     => 'section_start_ruby_reaction_general',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'General', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'single_post_reaction',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction Section', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the reaction section.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'       => 'unique_reaction',
					'type'     => 'switch',
					'title'    => esc_html__( 'One Reaction', 'pixwell' ),
					'subtitle' => esc_html__( 'Only one reaction per user. User reaction data will be refreshed if turn this option on/off.', 'pixwell' ),
					'switch'   => true,
					'default'  => 0
				),
				array(
					'id'     => 'section_end_ruby_reaction_general',
					'type'   => 'section',
					'class'  => 'ruby-section-end',
					'indent' => false
				),
				array(
					'id'     => 'section_start_ruby_reaction',
					'type'   => 'section',
					'class'  => 'ruby-section-start',
					'title'  => esc_html__( 'Reactions', 'pixwell' ),
					'indent' => true
				),
				array(
					'id'       => 'reaction_love',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Love', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the love reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_sad',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Sad', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the sad reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_happy',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Happy', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the happy reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_sleepy',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Sleepy', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the sleepy reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_angry',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Angry', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the angry reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_dead',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Dead', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the dead reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'       => 'reaction_wink',
					'type'     => 'switch',
					'title'    => esc_html__( 'Reaction - Wink', 'pixwell' ),
					'subtitle' => esc_html__( 'Enable or disable the wink reaction item.', 'pixwell' ),
					'switch'   => true,
					'default'  => 1
				),
				array(
					'id'     => 'section_end_ruby_reaction',
					'type'   => 'section',
					'class'  => 'ruby-section-end no-border',
					'indent' => false
				)
			)
		);
	}
}
